@@ -10,15 +10,16 @@
     :license: BSD, see LICENSE for details.
 """
 
-from os import path
-from datetime import datetime
 from collections import namedtuple
+from os import path
 
 from sphinx import package_dir
-from sphinx.config import string_classes, ENUM
 from sphinx.builders import _epub_base
+from sphinx.config import string_classes, ENUM
 from sphinx.util import logging, xmlname_checker
 from sphinx.util.fileutil import copy_asset_file
+from sphinx.util.i18n import format_date
+from sphinx.util.osutil import make_filename
 
 if False:
     # For type annotation
@@ -62,6 +63,7 @@ class Epub3Builder(_epub_base.EpubBuilder):
     an epub file.
     """
     name = 'epub'
+    epilog = 'The ePub file is in %(outdir)s.'
 
     supported_remote_images = False
     template_dir = path.join(package_dir, 'templates', 'epub3')
@@ -85,40 +87,37 @@ class Epub3Builder(_epub_base.EpubBuilder):
     def validate_config_value(self):
         # <package> lang attribute, dc:language
         if not self.app.config.epub_language:
-            self.app.warn(
-                'conf value "epub_language" (or "language") '
-                'should not be empty for EPUB3')
+            logger.warning('conf value "epub_language" (or "language") '
+                           'should not be empty for EPUB3')
         # <package> unique-identifier attribute
         if not xmlname_checker().match(self.app.config.epub_uid):
-            self.app.warn('conf value "epub_uid" should be XML NAME for EPUB3')
+            logger.warning('conf value "epub_uid" should be XML NAME for EPUB3')
         # dc:title
         if not self.app.config.epub_title:
-            self.app.warn(
-                'conf value "epub_title" (or "html_title") '
-                'should not be empty for EPUB3')
+            logger.warning('conf value "epub_title" (or "html_title") '
+                           'should not be empty for EPUB3')
         # dc:creator
         if not self.app.config.epub_author:
-            self.app.warn('conf value "epub_author" should not be empty for EPUB3')
+            logger.warning('conf value "epub_author" should not be empty for EPUB3')
         # dc:contributor
         if not self.app.config.epub_contributor:
-            self.app.warn('conf value "epub_contributor" should not be empty for EPUB3')
+            logger.warning('conf value "epub_contributor" should not be empty for EPUB3')
         # dc:description
         if not self.app.config.epub_description:
-            self.app.warn('conf value "epub_description" should not be empty for EPUB3')
+            logger.warning('conf value "epub_description" should not be empty for EPUB3')
         # dc:publisher
         if not self.app.config.epub_publisher:
-            self.app.warn('conf value "epub_publisher" should not be empty for EPUB3')
+            logger.warning('conf value "epub_publisher" should not be empty for EPUB3')
         # dc:rights
         if not self.app.config.epub_copyright:
-            self.app.warn(
-                'conf value "epub_copyright" (or "copyright")'
-                'should not be empty for EPUB3')
+            logger.warning('conf value "epub_copyright" (or "copyright")'
+                           'should not be empty for EPUB3')
         # dc:identifier
         if not self.app.config.epub_identifier:
-            self.app.warn('conf value "epub_identifier" should not be empty for EPUB3')
+            logger.warning('conf value "epub_identifier" should not be empty for EPUB3')
         # meta ibooks:version
         if not self.app.config.version:
-            self.app.warn('conf value "version" should not be empty for EPUB3')
+            logger.warning('conf value "version" should not be empty for EPUB3')
 
     def content_metadata(self):
         # type: () -> Dict
@@ -132,8 +131,9 @@ class Epub3Builder(_epub_base.EpubBuilder):
         metadata['contributor'] = self.esc(self.config.epub_contributor)
         metadata['page_progression_direction'] = PAGE_PROGRESSION_DIRECTIONS.get(writing_mode)
         metadata['ibook_scroll_axis'] = IBOOK_SCROLL_AXIS.get(writing_mode)
-        metadata['date'] = self.esc(datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%SZ"))
+        metadata['date'] = self.esc(format_date("%Y-%m-%dT%H:%M:%SZ"))
         metadata['version'] = self.esc(self.config.version)
+        metadata['epub_version'] = self.config.epub_version
         return metadata
 
     def prepare_writing(self, docnames):
@@ -144,6 +144,7 @@ class Epub3Builder(_epub_base.EpubBuilder):
         self.globalcontext['theme_writing_mode'] = THEME_WRITING_MODES.get(writing_mode)
         self.globalcontext['html_tag'] = self.html_tag
         self.globalcontext['use_meta_charset'] = self.use_meta_charset
+        self.globalcontext['skip_ua_compatible'] = True
 
     def build_navlist(self, navnodes):
         # type: (List[nodes.Node]) -> List[NavPoint]
@@ -225,15 +226,36 @@ class Epub3Builder(_epub_base.EpubBuilder):
 
 def setup(app):
     # type: (Sphinx) -> Dict[unicode, Any]
-
-    app.setup_extension('sphinx.builders.epub2')
-
     app.add_builder(Epub3Builder)
 
     # config values
-    app.add_config_value('epub_description', 'unknown', 'epub3', string_classes)
-    app.add_config_value('epub_contributor', 'unknown', 'epub3', string_classes)
-    app.add_config_value('epub_writing_mode', 'horizontal', 'epub3',
+    app.add_config_value('epub_basename', lambda self: make_filename(self.project), None)
+    app.add_config_value('epub_version', 3.0, 'epub')  # experimental
+    app.add_config_value('epub_theme', 'epub', 'epub')
+    app.add_config_value('epub_theme_options', {}, 'epub')
+    app.add_config_value('epub_title', lambda self: self.html_title, 'epub')
+    app.add_config_value('epub_author', 'unknown', 'epub')
+    app.add_config_value('epub_language', lambda self: self.language or 'en', 'epub')
+    app.add_config_value('epub_publisher', 'unknown', 'epub')
+    app.add_config_value('epub_copyright', lambda self: self.copyright, 'epub')
+    app.add_config_value('epub_identifier', 'unknown', 'epub')
+    app.add_config_value('epub_scheme', 'unknown', 'epub')
+    app.add_config_value('epub_uid', 'unknown', 'env')
+    app.add_config_value('epub_cover', (), 'env')
+    app.add_config_value('epub_guide', (), 'env')
+    app.add_config_value('epub_pre_files', [], 'env')
+    app.add_config_value('epub_post_files', [], 'env')
+    app.add_config_value('epub_exclude_files', [], 'env')
+    app.add_config_value('epub_tocdepth', 3, 'env')
+    app.add_config_value('epub_tocdup', True, 'env')
+    app.add_config_value('epub_tocscope', 'default', 'env')
+    app.add_config_value('epub_fix_images', False, 'env')
+    app.add_config_value('epub_max_image_width', 0, 'env')
+    app.add_config_value('epub_show_urls', 'inline', 'epub')
+    app.add_config_value('epub_use_index', lambda self: self.html_use_index, 'epub')
+    app.add_config_value('epub_description', 'unknown', 'epub', string_classes)
+    app.add_config_value('epub_contributor', 'unknown', 'epub', string_classes)
+    app.add_config_value('epub_writing_mode', 'horizontal', 'epub',
                          ENUM('horizontal', 'vertical'))
 
     return {
