@@ -40,7 +40,7 @@ with "\\?": b?'here: >>>(\\\\|/)xbb<<<((\\\\|/)r)?'
 HTML_WARNINGS = ENV_WARNINGS + """\
 %(root)s/index.rst:\\d+: WARNING: unknown option: &option
 %(root)s/index.rst:\\d+: WARNING: citation not found: missing
-%(root)s/index.rst:\\d+: WARNING: no matching candidate for image URI u'foo.\\*'
+%(root)s/index.rst:\\d+: WARNING: a suitable image for html builder not found: foo.\\*
 %(root)s/index.rst:\\d+: WARNING: Could not lex literal_block as "c". Highlighting skipped.
 """
 
@@ -507,7 +507,6 @@ def test_numfig_disabled_warn(app, warning):
     app.build()
     warnings = warning.getvalue()
     assert 'index.rst:47: WARNING: numfig is disabled. :numref: is ignored.' in warnings
-    assert 'index.rst:55: WARNING: no number is assigned for section: index' not in warnings
     assert 'index.rst:56: WARNING: invalid numfig_format: invalid' not in warnings
     assert 'index.rst:57: WARNING: invalid numfig_format: Fig %s %s' not in warnings
 
@@ -525,10 +524,10 @@ def test_numfig_disabled_warn(app, warning):
         (".//li/code/span", '^Table:%s$', True),
         (".//li/code/span", '^CODE_1$', True),
         (".//li/code/span", '^Code-%s$', True),
-        (".//li/code/span", '^foo$', True),
-        (".//li/code/span", '^bar_a$', True),
+        (".//li/a/span", '^Section 1$', True),
+        (".//li/a/span", '^Section 2.1$', True),
         (".//li/code/span", '^Fig.{number}$', True),
-        (".//li/code/span", '^Sect.{number}$', True),
+        (".//li/a/span", '^Sect.1 Foo$', True),
     ],
     'foo.html': [
         (".//div[@class='figure']/p[@class='caption']/"
