@@ -49,8 +49,10 @@ def test_theme_api(app, status, warning):
         theme.get_config('theme', 'foobar')
 
     # options API
-    with pytest.raises(ThemeError):
-        theme.get_options({'nonexisting': 'foo'})
+
+    options = theme.get_options({'nonexisting': 'foo'})
+    assert 'nonexisting' not in options.keys()
+
     options = theme.get_options(cfg.html_theme_options)
     assert options['testopt'] == 'foo'
     assert options['nosidebar'] == 'false'
@@ -110,3 +112,15 @@ def test_staticfiles(app, status, warning):
 
     result = (app.outdir / 'index.html').text()
     assert '<meta name="testopt" content="optdefault" />' in result
+
+
+@pytest.mark.sphinx(testroot='theming')
+def test_theme_sidebars(app, status, warning):
+    app.build()
+
+    # test-theme specifies globaltoc and searchbox as default sidebars
+    result = (app.outdir / 'index.html').text(encoding='utf8')
+    assert '<h3><a href="#">Table Of Contents</a></h3>' in result
+    assert '<h3>Related Topics</h3>' not in result
+    assert '<h3>This Page</h3>' not in result
+    assert '<h3>Quick search</h3>' in result
