@@ -10,13 +10,14 @@
 """
 from __future__ import print_function
 
-import os
 import datetime
+import os
 
 import pytest
 from babel.messages.mofile import read_mo
-from sphinx.util import i18n
+
 from sphinx.errors import SphinxError
+from sphinx.util import i18n
 
 
 def test_catalog_info_for_file_and_path():
@@ -176,6 +177,8 @@ def test_format_date():
     datet = datetime.datetime(2016, 2, 7, 5, 11, 17, 0)
     assert i18n.format_date(format, date=datet) == 'February 07, 2016, 05:11:17 05 AM'
 
+    format = '%B %-d, %Y, %-H:%-M:%-S %-I %p'
+    assert i18n.format_date(format, date=datet) == 'February 7, 2016, 5:11:17 5 AM'
     format = '%x'
     assert i18n.format_date(format, date=datet) == 'Feb 7, 2016'
     format = '%X'
